==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkPointSetAlgorithm.java <==
// java wrapper for vtkPointSetAlgorithm object
//

package vtk;
import vtk.*;

public class vtkPointSetAlgorithm extends vtkAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetOutput_2();
  public vtkPointSet GetOutput() {
    long temp = GetOutput_2();

    if (temp == 0) return null;
    return (vtkPointSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetOutput_3(int id0);
  public vtkPointSet GetOutput(int id0) {
    long temp = GetOutput_3(id0);

    if (temp == 0) return null;
    return (vtkPointSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetPolyDataOutput_4();
  public vtkPolyData GetPolyDataOutput() {
    long temp = GetPolyDataOutput_4();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetStructuredGridOutput_5();
  public vtkStructuredGrid GetStructuredGridOutput() {
    long temp = GetStructuredGridOutput_5();

    if (temp == 0) return null;
    return (vtkStructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetUnstructuredGridOutput_6();
  public vtkUnstructuredGrid GetUnstructuredGridOutput() {
    long temp = GetUnstructuredGridOutput_6();

    if (temp == 0) return null;
    return (vtkUnstructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetInputData_7(vtkDataObject id0);
  public void SetInputData(vtkDataObject id0)
    { SetInputData_7(id0); }

  private native void SetInputData_8(int id0,vtkDataObject id1);
  public void SetInputData(int id0,vtkDataObject id1)
    { SetInputData_8(id0,id1); }

  private native void SetInputData_9(vtkPointSet id0);
  public void SetInputData(vtkPointSet id0)
    { SetInputData_9(id0); }

  private native void SetInputData_10(int id0,vtkPointSet id1);
  public void SetInputData(int id0,vtkPointSet id1)
    { SetInputData_10(id0,id1); }

  private native void AddInputData_11(vtkDataObject id0);
  public void AddInputData(vtkDataObject id0)
    { AddInputData_11(id0); }

  private native void AddInputData_12(vtkPointSet id0);
  public void AddInputData(vtkPointSet id0)
    { AddInputData_12(id0); }

  private native void AddInputData_13(int id0,vtkPointSet id1);
  public void AddInputData(int id0,vtkPointSet id1)
    { AddInputData_13(id0,id1); }

  private native void AddInputData_14(int id0,vtkDataObject id1);
  public void AddInputData(int id0,vtkDataObject id1)
    { AddInputData_14(id0,id1); }

  private native long GetInput_15();
  public vtkDataObject GetInput() {
    long temp = GetInput_15();

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  public vtkPointSetAlgorithm() { super(); }

  public vtkPointSetAlgorithm(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-armv6h.pkg.tar.xz: vtk/vtkPointSetAlgorithm.java <==
// java wrapper for vtkPointSetAlgorithm object
//

package vtk;
import vtk.*;

public class vtkPointSetAlgorithm extends vtkAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetOutput_2();
  public vtkPointSet GetOutput() {
    long temp = GetOutput_2();

    if (temp == 0) return null;
    return (vtkPointSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetOutput_3(int id0);
  public vtkPointSet GetOutput(int id0) {
    long temp = GetOutput_3(id0);

    if (temp == 0) return null;
    return (vtkPointSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetPolyDataOutput_4();
  public vtkPolyData GetPolyDataOutput() {
    long temp = GetPolyDataOutput_4();

    if (temp == 0) return null;
    return (vtkPolyData)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetStructuredGridOutput_5();
  public vtkStructuredGrid GetStructuredGridOutput() {
    long temp = GetStructuredGridOutput_5();

    if (temp == 0) return null;
    return (vtkStructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetUnstructuredGridOutput_6();
  public vtkUnstructuredGrid GetUnstructuredGridOutput() {
    long temp = GetUnstructuredGridOutput_6();

    if (temp == 0) return null;
    return (vtkUnstructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetInputData_7(vtkDataObject id0);
  public void SetInputData(vtkDataObject id0)
    { SetInputData_7(id0); }

  private native void SetInputData_8(int id0,vtkDataObject id1);
  public void SetInputData(int id0,vtkDataObject id1)
    { SetInputData_8(id0,id1); }

  private native void SetInputData_9(vtkPointSet id0);
  public void SetInputData(vtkPointSet id0)
    { SetInputData_9(id0); }

  private native void SetInputData_10(int id0,vtkPointSet id1);
  public void SetInputData(int id0,vtkPointSet id1)
    { SetInputData_10(id0,id1); }

  private native void AddInputData_11(vtkDataObject id0);
  public void AddInputData(vtkDataObject id0)
    { AddInputData_11(id0); }

  private native void AddInputData_12(vtkPointSet id0);
  public void AddInputData(vtkPointSet id0)
    { AddInputData_12(id0); }

  private native void AddInputData_13(int id0,vtkPointSet id1);
  public void AddInputData(int id0,vtkPointSet id1)
    { AddInputData_13(id0,id1); }

  private native void AddInputData_14(int id0,vtkDataObject id1);
  public void AddInputData(int id0,vtkDataObject id1)
    { AddInputData_14(id0,id1); }

  private native long GetInput_15();
  public vtkDataObject GetInput() {
    long temp = GetInput_15();

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkPointSetAlgorithm() { super(); }

  public vtkPointSetAlgorithm(long id) { super(id); }
  public native long   VTKInit();

}
